@@ -25,7 +25,7 @@
 #'
 #' @export
 make_qrcode <- function(my_id, ec_level = 3){
-
+  
   assertthat::assert_that(!missing(my_id),
                           msg = "Please provide a unique ID.")
   assertthat::assert_that(ec_level >= 0 && ec_level <= 3, msg = "Please provide an error
@@ -64,6 +64,10 @@ make_qrcode <- function(my_id, ec_level = 3){
 #' @param family The font style to use to print labels.
 #' @param rounded Set to TRUE if label has round corners; set to false if label has
 #' square corners.
+#' @param print_across Set to TRUE to print labels across rows, left to right; else 
+#' set to FALSE to print labels down columns, top to bottom. Default is \code{TRUE}.
+#' @param rect Set to TRUE to draw rectangles around labels, else set to FALSE. 
+#' Default is \code{TRUE}.
 #' @param top_left_1 String for top-left row 1 position on a rectangular label.
 #' @param top_left_2 String for top-left row 2 position on a rectangular label.
 #' @param top_right_1 String for top-right row 1 position on a rectangular label.
@@ -88,6 +92,8 @@ make_qrcode <- function(my_id, ec_level = 3){
 #' create_label(
 #' font_sz = 10,
 #' filename = file, 
+#' print_across = TRUE,
+#' rect = TRUE,
 #' top_left_1 = paste("Plot:", 101:105), 
 #' top_left_2 = paste("Row:", c(rep(1, 3), rep(2, 2))), 
 #' top_right_1 = paste("Rep:", rep(1, 5)), 
@@ -122,6 +128,8 @@ create_label <- function(
     Treetag = FALSE,
     family = 'sans', # Font style to use
     rounded = TRUE, # Rounded corners
+    print_across = TRUE,
+    rect = TRUE,
     top_left_1 = NULL, # Text for top-left row 1
     top_left_2 = NULL, # Text for top-left row 2
     top_right_1 = NULL, # Text for top-right row 1
@@ -134,23 +142,23 @@ create_label <- function(
     unique_id = NULL, # Unique ids for QR codes
     ec_level = 3,
     ...){
-
+  
   error_numeric <- "must be a positive numeric value."
   error_flag <- "must be a logical or boolean value."
   error_string <- "must be string value."
-
+  
   # Function to check for positive values -- may have to be relocated
   is.valid_number <- function (x) {
     if (x >= 0 && assertthat::is.number(x)) return (TRUE) else return (FALSE)
   }
-
+  
   # Used in assertions to check if number is an integer and positive
   is.valid_count <- function (x) {
     if (x > 0 && assertthat::is.count(x)) return (TRUE) else return (FALSE)
   }
-
+  
   ## Assertions start --
-
+  
   # Checking all numeric inputs
   assertthat::assert_that(is.valid_number(wdt),
                           msg = paste("'wdt'", error_numeric))
@@ -174,24 +182,24 @@ create_label <- function(
                           msg = paste("'numcol'", "must be a positive integer."))
   assertthat::assert_that(is.valid_number(font_sz),
                           msg = paste("'font_sz'", error_numeric))
-
+  
   # Checking all flag inputs
-
+  
   assertthat::assert_that(assertthat::is.flag(Treetag),
                           msg = paste("'Treetag'", error_flag))
-
+  
   assertthat::assert_that(assertthat::is.flag(rounded),
                           msg = paste("'rounded'", error_flag))
-
-
+  
+  
   # Checking all string inputs
-
+  
   assertthat::assert_that(assertthat::is.string(filename),
                           msg = paste("'filename'", error_string))
-
+  
   assertthat::assert_that(assertthat::is.string(family),
                           msg = paste("'family'", error_string))
-
+  
   # assertthat::assert_that(assertthat::is.string(top_left_1),
   #                         msg = paste("'top_left_1'", error_string))
   #
@@ -218,23 +226,23 @@ create_label <- function(
   #
   # assertthat::assert_that(assertthat::is.string(bottom_left_2),
   #                         msg = paste("'bottom_left_2'", error_string))
-
+  
   ## -- Assertions end
-
+  
   # Calculate space between label columns if any
   if (numcol == 1) {
     col_space <- 0
   } else {
     col_space <- (page_wdt - left_mar - right_mar - numcol*wdt)/(numcol-1)
   }
-
+  
   # Calculate space between label rows if any
   if (numrow == 1) {
     row_space <- 0
   } else {
     row_space <- (page_hgt - top_mar - bot_mar - numrow*hgt)/(numrow-1)
   }
-
+  
   # Check if page setup matches label setup per page.
   # Error message if either column spaces or the row spaces between labels 
   # are less than zero
@@ -242,75 +250,75 @@ create_label <- function(
   if (col_space < 0 | row_space < 0) {
     stop("Page setup does not match label setup per page.")
   }
-
+  
   # clean up any open graphical devices if function fails
   on.exit(grDevices::graphics.off())
-
-
+  
+  
   # Create text for top-left row 1 -- plot id
   if (!is.null(top_left_1)) {
     plotid <- top_left_1
   } else {
     plotid <- NULL
   }
-
+  
   # Create text for top-left row 2 -- row id
   if (!is.null(top_left_2)) {
     rowid <- top_left_2
   } else {
     rowid <- NULL
   }
-
+  
   # Create text for top-right row 1 -- rep id
   if (!is.null(top_right_1)) {
     repid <- top_right_1
   } else {
     repid <- NULL
   }
-
+  
   # Create text for top-right row 2 -- col id
   if (!is.null(top_right_2)) {
     colid <- top_right_2
   } else {
     colid <- NULL
   }
-
-
+  
+  
   # Create text for center-right row 1 -- iblock id
   if (!is.null(center_right_1)) {
     blkid <- center_right_1
   } else {
     blkid <- NULL
   }
-
+  
   # Create text for center-right row 2 -- seed source id
   if (!is.null(center_right_2)) {
     sds <- center_right_2
   } else {
     sds <- NULL
   }
-
+  
   # Create text for center-right row 3 -- researcher's name id
   if (!is.null(center_right_3)) {
     rname <- center_right_3
   } else {
     rname <- NULL
   }
-
+  
   # Create text for bottom-left row 1 -- loc id
   if (!is.null(bottom_left_1)) {
     loc1 <- bottom_left_1
   } else {
     loc1 <- NULL
   }
-
+  
   # Create text for bottom-left row 2 -- loc id
   if (!is.null(bottom_left_2)) {
     entry <- bottom_left_2
   } else {
     entry <- NULL
   }
-
+  
   # Create QR codes from unique ids
   if (!is.null(unique_id)) {
     bb <- unique_id |> purrr::map(\(x) make_qrcode(ec_level = ec_level, x))
@@ -318,52 +326,61 @@ create_label <- function(
   } else {
     stop("Unique IDs for generating QR codes are missing!!")
   }
-
-
+  
+  
   # Generate label positions -- prints across rows of grid layout
-  pos <- expand.grid(x = 1:numcol, y = 1:numrow)
-
+  if (print_across == TRUE) {
+    
+    pos <- expand.grid(x = 1:numcol, y = 1:numrow)
+    
+  } else {
+    
+    pos <- expand.grid(y = 1:numrow, x = 1:numcol)
+    
+  }
+  
+  
   duplication <- ceiling(nn/nrow(pos))
-
+  
   label_pos <- do.call("rbind", replicate(duplication, pos, simplify = FALSE))
-
+  
   corx <- label_pos$x # label x coordinate
-
+  
   cory <- label_pos$y # label y coordinate
-
-
+  
+  
   # Create pdf file to be saved in working directory
-
+  
   filename <- paste0(filename, paste0(wdt,'in'), 'x',
                      paste0(hgt,'in'), Sys.time()) # name of pdf file
-
+  
   filename <- paste0(gsub(":","_", filename), ".pdf")
-
+  
   # Font size to print text on labels
   fsize <- font_sz
-
+  
   # Define new coordinates for QR code
   wdt1 <- 0.5 * wdt
   hgt1 <- 0.5 * hgt
-
+  
   qry <- hgt1/1.2
-
+  
   # Create pdf file
   # The argument family specifies the initial/default font family to be
   # used. Device independent fonts that can be used include 'sans', 'serif' and
   # 'mono', default is sans.
-
+  
   grDevices::pdf(filename,
                  width = page_wdt,
                  height = page_hgt,
                  onefile = TRUE,
                  family = family) # Letter size paper from Avery
-
+  
   # Grid layout for labels
   label_layout <- grid::grid.layout(numrow, numcol,
                                     widths = grid::unit(c(rep(wdt + col_space, numcol-1), wdt), "in"),
                                     heights = grid::unit(c(rep(hgt + row_space, numrow-1), hgt), "in"))
-
+  
   if (Treetag == TRUE) {
     # Viewport for first QR codes
     qq <- grid::viewport(x = grid::unit(0.57, "npc"),
@@ -372,7 +389,7 @@ create_label <- function(
                          width = grid::unit(wdt1, "in"),
                          height = grid::unit(qry, "in"),
                          just = c('right','center'))
-
+    
     # Viewport for IBlock
     bl <- grid::viewport(x = grid::unit(0.1, "npc"),
                          y = grid::unit(0.3, "npc"),
@@ -380,292 +397,302 @@ create_label <- function(
                          width = grid::unit(0.55*wdt, "in"),
                          height = grid::unit(0.8*hgt1, "in"),
                          just = "left")
-
+    
     # Viewport for second QR code
     qq2 <- grid::viewport(x = grid::unit(0.5, "npc"),
                           y = grid::unit(0.9, "npc"),
                           width = grid::unit(wdt1, "inches"),
                           height = grid::unit(qry, "inches"),
                           just = c('center'))
-
+    
     px <- 0.11*wdt # x coordinate for plot
-
+    
     py <- 0.05*hgt # y coordinate for plot
-
+    
     rx <- 0.27*wdt # x coordinate for row
-
+    
     ry <- 0.4*hgt # y coordinate for Rep
-
+    
     lx <- 0.9*wdt # x coordinate for location
-
+    
     ly <- 0.4*hgt # y coordinate for location
-
+    
     ex <- 0.9*wdt # x coordinate for first entry
-
+    
     ee <- 0.85*wdt # x coordinate for second entry
-
+    
     ey <- 0.83*hgt # y coordinate for second entry
-
+    
     nx <- 0.6*wdt # x coordinate for researcher's name
-
-
+    
+    
   } else {
-
+    
     # Create a viewport for each label
     aa <- grid::viewport(x = grid::unit(0, "npc"),
                          y = grid::unit(1, "npc"),
                          width = grid::unit(wdt, "in"),
                          height = grid::unit(hgt, "in"),
                          just = c('left','top'))
-
+    
     # Define viewport for QR code; note coordinates and dimension
-
+    
     qq <- grid::viewport(x = grid::unit(0.5, "npc"),
                          width = grid::unit(wdt1, "in"),
                          height = grid::unit(qry, "in"),
                          just = c('right','center'))
-
+    
     # Define viewport for Block ID if it is an incomplete block design
-
+    
     bl <- grid::viewport(x = grid::unit(0.47, "npc"),
                          width = grid::unit(0.55*wdt, "in"),
                          height = grid::unit(0.8*hgt1, "in"),
                          just = "left")
-
+    
     # Coordinates for adding text labels to grids
     px <- 0.1*wdt # x coordinate for plot
-
+    
     py <- 0.92*hgt # y coordinate for plot
-
+    
     rx <- 0.6*wdt # x coordinate for rep
-
+    
     ry <- 0.78*hgt # y coordinate for row
-
+    
     ly <- 0.22*hgt # y coordinate for location
-
+    
     ex <- 0.05*wdt # x coordinate for entry
-
+    
     ey <- 0.1*hgt # y coordinate for entry
-
+    
   }
-
+  
   # Viewport for a new page
   new.page <- grid::viewport(width = grid::unit(page_wdt, "in"),
                              height = grid::unit(page_hgt, "in"))
-
+  
   # Create a viewport for each page using grid layout
   lab_vp <- grid::viewport(layout = label_layout)
   grid::pushViewport(lab_vp)
-
+  
   bold_font <- grid::gpar(fontface = "bold", fontsize = fsize)
   bold_font2 <- grid::gpar(fontface = "bold", fontsize = fsize-2)
   plain_font2 <- grid::gpar(fontface = "plain", fontsize = fsize-2)
   plain_font3 <- grid::gpar(fontface = "plain", fontsize = fsize-4)
   bold_font3 <- grid::gpar(fontface = "bold", fontsize = fsize-4)
   plain_font4 <- grid::gpar(fontface = "plain", fontsize = floor(fsize/2.5))
-
+  
   # Define progres bar parameters
   pro_bar <- txtProgressBar(min = 0, max = nn, style = 3, char = '=')
-
+  
   for (i in seq_len(nn)) {
-
+    
     # set progress bar to chromosome indexing
     setTxtProgressBar(pro_bar, value = i)
-
+    
     label_posn <- c(x = corx[i], y = cory[i])
-
-
+    
+    
     if (all(i != 1 & label_posn == c(1, 1))) {
       grid::grid.newpage()
-
+      
       grid::pushViewport(new.page)
       grid::pushViewport(lab_vp)
-
+      
     }
-
+    
     if (Treetag == TRUE) {
       tt <- grid::viewport(layout.pos.row=label_posn['y'],
                            layout.pos.col=label_posn['x'])
-
+      
       grid::pushViewport(tt)
-
-      if (rounded == TRUE) {
-        grid::grid.roundrect(gp = grid::gpar(lwd = 0.5))
-      } else (grid::grid.rect(gp = grid::gpar(lwd = 0.5)))
-
+      
+      # Draw rectangle around labels
+      if (rect == TRUE) {
+        
+        if (rounded == TRUE) {
+          grid::grid.roundrect(gp = grid::gpar(lwd = 0.5))
+        } else (grid::grid.rect(gp = grid::gpar(lwd = 0.5)))
+        
+      } 
+      
       # Add Plot ID to label; note coordinates
       grid::grid.text(label = plotid[i],
                       x = grid::unit(px, "in"),
                       y = grid::unit(py, "in"), rot = 90,
                       gp = bold_font, hjust = 0, vp = tt)
-
+      
       # Add Rep ID to label; note coordinates
       grid::grid.text(label = repid[i],
                       x = grid::unit(px, "in"),
                       y = grid::unit(ry, "in"), rot = 90,
                       gp = bold_font, hjust = 0, vp = tt)
-
+      
       # Add Row ID to label; note coordinates
       grid::grid.text(label = rowid[i],
                       x = grid::unit(rx, "in"),
                       y = grid::unit(py, "in"), rot = 90,
                       gp = bold_font2, hjust = 0, vp = tt)
-
+      
       # Add column ID to label; note coordinates
       grid::grid.text(label = colid[i],
                       x = grid::unit(rx, "in"),
                       y = grid::unit(ry, "in"), rot = 90,
                       gp = bold_font2, hjust = 0, vp = tt)
-
-
+      
+      
       # Define viewport for QR code; note coordinates and dimension
-
+      
       grid::pushViewport(qq)
-
+      
       # Add first QR code
       grid::grid.draw(bb[[i]])
       grid::popViewport()
-
+      
       # Define viewport for Block ID if it is an incomplete block design
-
+      
       grid::pushViewport(bl)
-
+      
       # Add Block ID to label; note coordinates
       grid::grid.text(label = blkid[i],
                       x = grid::unit(0.2, "npc"),
                       y = grid::unit(0.35, "npc"),
                       rot = 360, gp = plain_font2, hjust = 0)
-
-
+      
+      
       # Go back to label viewport
       grid::upViewport()
-
+      
       # Add location of experiment to label
       grid::grid.text(label = loc1[i], rot = 90,
                       x = grid::unit(lx, "in"),
                       y = grid::unit(ly, "in"),
                       gp = plain_font4, hjust = 0, vp = tt)
-
+      
       # Add seed source to label; note coordinates
       grid::grid.text(label = sds[i],
                       x = grid::unit(0.6, "npc"),
                       y = grid::unit(0.35, "npc"),
                       rot = 90, vp = tt,
                       gp = plain_font3, hjust = 0, )
-
+      
       # Add researcher's name to label; note coordinates
       grid::grid.text(label = rname,
                       x = grid::unit(0.72, "npc"),
                       y = grid::unit(0.35, "npc"),
                       rot = 90, vp = tt,
                       gp = plain_font3, hjust = 0, )
-
-
+      
+      
       # Add entry or treatment name to label
       grid::grid.text(label = entry[i], rot = 90,
                       x = grid::unit(ex, "in"),
                       y = grid::unit(py, "in"),
                       gp = bold_font3, hjust = 0, vp = tt)
-
+      
       # Add entry or treatment name to label tear-off
       grid::grid.text(label = entry[i], rot = 90,
                       x = grid::unit(ee, "in"),
                       y = grid::unit(ey, "in"),
                       gp = plain_font4, hjust = 0, vp = tt)
-
+      
       grid::pushViewport(qq2)
-
+      
       # Add second QR code
       grid::grid.draw(bb[[i]])
-
+      
       grid::popViewport(2)
-
+      
     } else {
-
+      
       grid::pushViewport(grid::viewport(layout.pos.row=label_posn['y'],
                                         layout.pos.col=label_posn['x']))
       grid::pushViewport(aa)
-
-      if (rounded == TRUE) {
-        grid::grid.roundrect(gp = grid::gpar(lwd = 0.5))
-      } else (grid::grid.rect(gp = grid::gpar(lwd = 0.5)))
-
+      
+      # Draw rectangle around labels
+      if (rect == TRUE) {
+        
+        if (rounded == TRUE) {
+          grid::grid.roundrect(gp = grid::gpar(lwd = 0.5))
+        } else (grid::grid.rect(gp = grid::gpar(lwd = 0.5)))
+        
+      } 
+      
       # Add Plot ID to label; note coordinates
       grid::grid.text(label = plotid[i],
                       x = grid::unit(px, "in"),
                       y = grid::unit(py, "in"),
                       gp = bold_font, hjust = 0, vp = aa)
-
+      
       # Add Rep ID to label; note coordinates
       grid::grid.text(label = repid[i],
                       x = grid::unit(rx, "in"),
                       y = grid::unit(py, "in"),
                       gp = bold_font, hjust = 0, vp = aa)
-
+      
       # Add Row ID to label; note coordinates
       grid::grid.text(label = rowid[i],
                       x = grid::unit(px, "in"),
                       y = grid::unit(ry, "in"),
                       gp = bold_font2, hjust = 0, vp = aa)
-
+      
       # Add column ID to label; note coordinates
       grid::grid.text(label = colid[i],
                       x = grid::unit(rx, "in"),
                       y = grid::unit(ry, "in"),
                       gp = bold_font2, hjust = 0, vp = aa)
-
+      
       # Add seed source to label; note coordinates
       grid::grid.text(label = sds[i],
                       x = grid::unit(0.42, "npc"),
                       y = grid::unit(0.47, "npc"),
                       gp = plain_font3, hjust = 0, vp = aa)
-
+      
       # Add researcher's name to label; note coordinates
       grid::grid.text(label = rname,
                       x = grid::unit(0.42, "npc"),
                       y = grid::unit(0.35, "npc"),
                       gp = plain_font3, hjust = 0, vp = aa)
-
+      
       # Push viewport for qr code
-
+      
       grid::pushViewport(qq)
-
+      
       # Add QR code
       grid::grid.draw(bb[[i]])
       grid::popViewport()
-
+      
       # Define viewport for Block ID if it is an incomplete block design
-
+      
       grid::pushViewport(bl)
-
+      
       # Add Block ID to label; note coordinates
       # Add Block ID to label; note coordinates
-
+      
       grid::grid.text(label = blkid[i],
                       x = grid::unit(0.01, "npc"),
                       y = grid::unit(0.8, "npc"),
                       gp = plain_font3, hjust = 0)
-
+      
       # Go back to label viewport
       grid::upViewport()
-
+      
       # Add location of experiment to label
       grid::grid.text(label = loc1[i],
                       x= grid::unit(px, "in"),
                       y = grid::unit(ly, "in"),
                       gp = plain_font4, hjust = 0, vp = aa)
-
+      
       # Add entry or treatment name to label
       grid::grid.text(label = entry[i],
                       x= grid::unit(ex, "in"),
                       y = grid::unit(ey, "in"),
                       gp = bold_font3, hjust = 0, vp = aa)
-
+      
       grid::popViewport(2)
     }
-
+    
   }
-
+  
 } # End of create_label ()
 
 
@@ -798,21 +825,21 @@ field_label <- function(dat,
                         IBlock_id = 'IBLOCK', # Input id for IBLOCK
                         seed_source_id = NULL,
                         ...){
-
+  
   error_numeric <- "must be a positive numeric value."
   error_flag <- "must be a logical or boolean value."
   error_string <- "must be string value."
-
+  
   # Function to check for positive values -- may have to be relocated
   is.valid_number <- function (x) {
     if (x >= 0 && assertthat::is.number(x)) return (TRUE) else return (FALSE)
   }
-
+  
   # Used in assertions to check if number is an integer and positive
   is.valid_count <- function (x) {
     if (x > 0 && assertthat::is.count(x)) return (TRUE) else return (FALSE)
   }
-
+  
   # Assertion for dat argument
   assertthat::assert_that(!missing(dat),
                           msg = "Fieldbook is missing, please provide a fieldbook as a data frame.")
@@ -820,26 +847,26 @@ field_label <- function(dat,
   # Checking all flag inputs
   assertthat::assert_that(assertthat::is.flag(seed_source),
                           msg = paste("'seed_source'", error_flag))
-
+  
   assertthat::assert_that(assertthat::is.flag(IBlock),
                           msg = paste("'IBlock'", error_flag))
-
+  
   # Checking all string inputs
   assertthat::assert_that(get_unique_id %in% c("ruid", "uuid", "custom"),
                           msg = paste("'get_unique_id' must be a string value",
                                       "of one of these: 'ruid','uuid' or 'custom'"))
   if (get_unique_id == "custom" & is.null(unique_id)) {
     stop(paste("Use the 'unique_id' argument to specify the column name in your fieldbook containing unique ids."))
-
+    
   }
-
+  
   if (seed_source == TRUE & is.null(seed_source_id)) {
     stop(paste("Use the 'seed_source_id' argument to specify the column name in your fieldbook containing seed source ids."))
   }
-
-
+  
+  
   # Checking all flag inputs
-
+  
   assertthat::assert_that(assertthat::is.string(Trial),
                           msg = paste("'Trial'", error_string))
   assertthat::assert_that(assertthat::is.string(rep_id),
@@ -856,96 +883,96 @@ field_label <- function(dat,
                           msg = paste("'entry_id'", error_string))
   assertthat::assert_that(assertthat::is.string(IBlock_id),
                           msg = paste("'IBlock_id'", error_string))
-
+  
   # Assert inputs with NULL arguments as default if overwritten by the user
   if (!is.null(Year)) {
     assertthat::assert_that((assertthat::is.string(Year) || is.valid_number(Year)) && nchar(Year) == 4,
                             msg = "Year must be a string or numeric value of four characters.")
   }
-
+  
   if (!is.null(seed_source_id)) {
     assertthat::assert_that(assertthat::is.string(seed_source_id),
                             msg = "Seed source ID must be a string value.")
   }
-
+  
   if (!is.null(rname)) {
     assertthat::assert_that(assertthat::is.string(rname),
                             msg = "Researcher name must be a string value.")
   }
-
+  
   # if (!is.null(unique_id)) {
   #   assertthat::assert_that(assertthat::is.string(unique_id),
   #                           msg = "'unique_id' must be a string value.")
   # }
-
+  
   # Define year for experiment
   if (is.null(Year) == TRUE) {
     yr <- format(Sys.time(),'%Y')
   } else {
     yr <- as.character(Year)
   }
-
+  
   plotid <- paste("Plot ID:", dat[, plot_id]) # Plot ids
-
+  
   repid <- paste("Rep ID:", dat[, rep_id]) # Rep ids
-
+  
   loc1 <- paste("Loc:", dat[, loc_id]) # Location ids
-
+  
   rowid <- paste("Row ID:", dat[, row_id]) # Row ids
-
+  
   colid <- paste("Col. ID:", dat[, col_id]) # Column ids
-
+  
   entry <-  dat[, entry_id]
-
+  
   rnames <- rep(rname, nrow(dat)) # Researcher's name
-
+  
   # Block ids if it is an incomplete block design
   if (IBlock == TRUE) {
     iblock <- dat[, IBlock_id]
-    blkid <- paste("IBlock ID:", iblock)
+    blkid <- paste("B:", iblock)
   } else {
-    blkid <- rep('No IBlock', nrow(dat))
+    blkid <- NULL
   }
-
-
+  
+  
   # Show seed source on label
   if (seed_source == TRUE) {
-
-    sds <- paste("Seed:", dat[, seed_source_id])
-
+    
+    sds <- paste(dat[, seed_source_id])
+    
   } else {
     sds <- NULL
   }
-
+  
   # Create unique id: if 'ruid' (i.e. Reproducible Unique IDs), the function concatenates
   # loc, year, trial name, plot, row and column. if 'uuid' (i.e. Universal Unique IDs),
   # the function generates UUIDs by time randomly. Note that UUIDs are uninformative and not reproducible.
   # If 'custom', user must use the 'unique_id' argument to specify the column name
   # in field book that denotes custom generated unique IDs.
-
+  
   if (get_unique_id == "ruid"){
-
+    
     trial_name <- gsub(" ", "_", Trial)
-
+    
     loc <- dat[, loc_id]
     plott <- dat[, plot_id]
     roww <- dat[, row_id]
     coll <- dat[, col_id]
-
+    
     UNIQUE_ID <- paste(paste0(gsub(" ", "", loc), yr),
                        trial_name, plott, roww, coll, sep = "_" )
-
+    
   } else if (get_unique_id == "uuid") {
     UNIQUE_ID <- uuid::UUIDgenerate(use.time = TRUE, n = nrow(dat), output = "string")
-
+    
   } else if (get_unique_id == "custom") {
     UNIQUE_ID <- dat[, unique_id]
   }
-
+  
   # Create an augmented field book containing unique IDs
   updat <- dplyr::mutate(dat, UNIQUE_ID)
   colnames(updat)[ncol(updat)] <- 'UNIQUE_ID'
-
+  
   if (colnames(updat)[1] == 'ID') {
     colnames(updat)[1] <- 'SN'
   } else {
@@ -957,10 +984,10 @@ field_label <- function(dat,
     paste0("Updated_Fieldbook_", ... = _, ".csv")
   
   utils::write.csv(updat, file = paste0(filename, ts), row.names = FALSE)
-
+  
   # Send updated fieldbook from package environment to global environment
   #.GlobalEnv$updated_fieldbook <- list(updated_fieldbook = updat)
-
+  
   do.call(create_label, args = list(top_left_1 = plotid,
                                     top_left_2 = rowid,
                                     top_right_1 = repid,
@@ -968,11 +995,11 @@ field_label <- function(dat,
                                     center_right_1 = blkid,
                                     center_right_2 = sds,
                                     center_right_3 = rnames,
-                                    bottom_left_1 = loc1,
+                                    bottom_left_1 = UNIQUE_ID,
                                     bottom_left_2 = entry,
                                     unique_id = UNIQUE_ID, 
                                     filename = filename, ...))
-
+  
   #cat("\n\n\tGenerated labels and updated fieldbook saved to working directory.")
 }
 
@@ -1097,9 +1124,9 @@ gp_label <- function(dat,
   # Assertion for dat argument
   assertthat::assert_that(!missing(dat),
                           msg = "Fieldbook is missing, please provide a fieldbook as a data frame.")
-
+  
   error_prompt <- "Invalid string entered for"
-
+  
   # Text for top-left row 1
   if (!is.null(top_left_id1)) {
     assertthat::assert_that(assertthat::is.string(top_left_id1),
@@ -1108,7 +1135,7 @@ gp_label <- function(dat,
   } else {
     topleft1 <- top_left_txt1
   }
-
+  
   # Text for top-left row 2
   if (!is.null(top_left_id2)) {
     assertthat::assert_that(assertthat::is.string(top_left_id2),
@@ -1117,7 +1144,7 @@ gp_label <- function(dat,
   } else {
     topleft2 <- top_left_txt2
   }
-
+  
   # Text for top-right row 1
   if (!is.null(top_right_id1)) {
     assertthat::assert_that(assertthat::is.string(top_right_id1),
@@ -1126,7 +1153,7 @@ gp_label <- function(dat,
   } else {
     topright1 <- top_right_txt1
   }
-
+  
   # Text for top-right row 2
   if (!is.null(top_right_id2)) {
     assertthat::assert_that(assertthat::is.string(top_right_id2),
@@ -1135,7 +1162,7 @@ gp_label <- function(dat,
   } else {
     topright2 <- top_right_txt2
   }
-
+  
   # Text for center-right row 1
   if (!is.null(center_right_id1)) {
     assertthat::assert_that(assertthat::is.string(center_right_id1),
@@ -1144,7 +1171,7 @@ gp_label <- function(dat,
   } else {
     centerright1 <- center_right_txt1
   }
-
+  
   # Text for center-right row 2
   if (!is.null(center_right_id2)) {
     assertthat::assert_that(assertthat::is.string(center_right_id2),
@@ -1153,7 +1180,7 @@ gp_label <- function(dat,
   } else {
     centerright2 <- center_right_txt2
   }
-
+  
   # Text for center-right row 3
   if (!is.null(center_right_id3)) {
     assertthat::assert_that(assertthat::is.string(center_right_id3),
@@ -1162,7 +1189,7 @@ gp_label <- function(dat,
   } else {
     centerright3 <- center_right_txt3
   }
-
+  
   # Text for bottom-left row 1
   if (!is.null(bottom_left_id1)) {
     assertthat::assert_that(assertthat::is.string(bottom_left_id1),
@@ -1171,7 +1198,7 @@ gp_label <- function(dat,
   } else {
     bottomleft1 <- bottom_left_txt1
   }
-
+  
   # Text for bottom-left row 2
   if (!is.null(bottom_left_id2)) {
     assertthat::assert_that(assertthat::is.string(bottom_left_id2),
@@ -1180,23 +1207,23 @@ gp_label <- function(dat,
   } else {
     bottomleft2 <- bottom_left_txt2
   }
-
+  
   # Create unique id: if 'uuid' (i.e. Universal Unique IDs),
   # the function generates UUIDs by time randomly. Note that UUIDs are uninformative and not reproducible.
   # If 'custom', user must use the 'unique_id' argument to specify the column name
   # in fieldbook that denotes custom generated unique IDs.
-
+  
   if (get_unique_id == "uuid") {
     UNIQUE_ID <- uuid::UUIDgenerate(use.time = TRUE, n = nrow(dat), output = "string")
-
+    
   } else if (get_unique_id == "custom") {
     UNIQUE_ID <- dat[, unique_id]
   }
-
+  
   # Create an augmented fieldbook containing unique IDs
   updat <- dplyr::mutate(dat, UNIQUE_ID)
   colnames(updat)[ncol(updat)] <- 'UNIQUE_ID'
-
+  
   if (colnames(updat)[1] == 'ID') {
     colnames(updat)[1] <- 'SN'
   } else {
@@ -1206,12 +1233,12 @@ gp_label <- function(dat,
   # File name and timestamp for updated fieldbook
   ts <- Sys.time() |> format(format = "%H_%M_%S") |> 
     paste0("Updated_Fieldbook_", ... = _, ".csv")
-
+  
   utils::write.csv(updat, file = paste0(filename, ts), row.names = FALSE)
-
+  
   # Send updated fieldbook from package environment to global environment
   #.GlobalEnv$updated_fieldbook <- list(updated_fieldbook = updat)
-
+  
   do.call(create_label, args = list(top_left_1 = topleft1, 
                                     top_left_2 = topleft2,
                                     top_right_1 = topright1, 
@@ -1223,7 +1250,7 @@ gp_label <- function(dat,
                                     bottom_left_2 = bottomleft2,
                                     unique_id = UNIQUE_ID, 
                                     filename = filename, ...))
-
+  
   #cat("\n\n\tGenerated labels and updated fieldbook saved to working directory.")
 }
 
@@ -1263,6 +1290,10 @@ gp_label <- function(dat,
 #' @param family The font style to use to print labels.
 #' @param rounded Set to TRUE if label has round corners; set to false if label has
 #' square corners.
+#' @param print_across Set to TRUE to print labels across rows, left to right; else 
+#' set to FALSE to print labels down columns, top to bottom. Default is \code{TRUE}.
+#' @param rect Set to TRUE to draw rectangles around labels, else set to FALSE. 
+#' Default is \code{TRUE}.
 #' @param bot_txt1 The prefix text for bottom text position 1.
 #' @param bot_txt2 The prefix text for bottom text position 2.
 #' @param bot_txt3 The prefix text for bottom text position 3.
@@ -1322,6 +1353,8 @@ gp_label <- function(dat,
 #' font_sz = 10,
 #' family = 'sans',
 #' rounded = TRUE,
+#' print_across = TRUE,
+#' rect = TRUE,
 #' bot_txt1 = 'Rubi',
 #' cent_txt2 = 'Rep:',
 #' cent_txt3 = 'R:',
@@ -1359,6 +1392,8 @@ gp_label_portrait <- function(
     font_sz = 8,
     family = 'sans', # Font style to use
     rounded = TRUE, # Rounded corners
+    print_across = TRUE, # print across from left to right
+    rect = TRUE, # draw rectangles around label
     bot_txt1 = NULL, # Bottom position position text 1
     bot_txt2 = NULL, # Bottom position text 2
     bot_txt3 = NULL, # Bottom position text 3
@@ -1578,7 +1613,15 @@ gp_label_portrait <- function(
   
   
   # Generate label positions -- prints across rows of grid layout
-  pos <- expand.grid(x = 1:numcol, y = 1:numrow)
+  if (print_across == TRUE) {
+    
+    pos <- expand.grid(x = 1:numcol, y = 1:numrow)
+    
+  } else {
+    
+    pos <- expand.grid(y = 1:numrow, x = 1:numcol)
+    
+  }
   
   duplication <- ceiling(nn/nrow(pos))
   
@@ -1695,9 +1738,14 @@ gp_label_portrait <- function(
                                       layout.pos.col=label_posn['x']))
     grid::pushViewport(aa)
     
-    if (rounded == TRUE) {
-      grid::grid.roundrect(gp = grid::gpar(lwd = 0.5))
-    } else (grid::grid.rect(gp = grid::gpar(lwd = 0.5)))
+    # Draw rectangle around labels
+    if (rect == TRUE) {
+      
+      if (rounded == TRUE) {
+        grid::grid.roundrect(gp = grid::gpar(lwd = 0.5))
+      } else (grid::grid.rect(gp = grid::gpar(lwd = 0.5)))
+      
+    } 
     
     # Add text1 to label (bottom position 1); note coordinates
     grid::grid.text(label = text1[i],
